@@ -17,7 +17,7 @@ use File::TypeCategories;
 use Clone qw/clone/;
 use Path::Tiny;
 
-our $VERSION = version->new('0.7.0');
+our $VERSION = version->new('0.7.1');
 
 has regex => (
     is       => 'rw',
@@ -261,7 +261,7 @@ File::CodeSearch - Search file contents in code repositories
 
 =head1 VERSION
 
-This documentation refers to File::CodeSearch version 0.7.0.
+This documentation refers to File::CodeSearch version 0.7.1.
 
 =head1 SYNOPSIS
 
@@ -270,7 +270,7 @@ This documentation refers to File::CodeSearch version 0.7.0.
    # Simple usage
    code_search {
        my ($file, $line) = @_;
-       // do stuff
+       # do stuff
    },
    @dirs;
 
